==> pypans-0.0.13.tar.gz: pypans-0.0.13/CHANGELOG.md <==
Versions
========

0.0.13
========

_Release date: 30.05.2020_

- Integrate interrogate docstring tool

0.0.12
========

_Release date: 10.05.2020_

- Introduce github.io pages configuration file
- Split supported python versions with comma
- Set theme jekyll-theme-cayman
- Implement colored output
- Implement line multiplier
- Return success for code analysis tool

0.0.11
========

_Release date: 23.04.2020_

- Update code badges according to new organisation

0.0.10
========

_Release date: 22.04.2020_

- Add 'flake8-printf-formatting' package

0.0.9
========

_Release date: 16.04.2020_

- Make analyser executable
- Introduce 'check-manifest' tool

0.0.8
========

_Release date: 16.04.2020_

- Upgrade 'enforce-pep8' package
- Ignore 'I100' flake8 rule
- Describe additional meta data for packaging
- Conform python class naming with forward dunder

0.0.7
========

_Release date: 14.04.2020_

- Include Procfile into packaging

0.0.6
========

_Release date: 14.04.2020_

- Save current installed python dependencies
- Add PYPI badges

0.0.5
========

_Release date: 10.04.2020_

- Enhance pypan tool help
- Introduce extra packaging files
- Add pretty python interpreters to dev requirements
- Support 'pytest-mock' plugin
- Upgrade 'enforce-pep8' package

0.0.4
========

_Release date: 06.04.2020_

- Use 100 lines of code
- Support 'back to top' readme navigation

0.0.3
========

_Release date: 05.04.2020_

- Specify local debug section

0.0.2
========

_Release date: 05.04.2020_

- Describe demo usage

0.0.1
========

_Release date: 05.04.2020_

- Support colored user prompt
- Build project environment setup
- Include runtime.txt template file
- Fix code analyser linters
- Show tool usage
- Add 'disallow_subclassing_any' argument to mypy tool
- Introduce template folder
- Introduce package template metafiles
- Define 'pypans' package name
- Introduce initial version of a project

==> pypans-0.0.14.tar.gz: pypans-0.0.14/CHANGELOG.md <==
Versions
========

0.0.14
========

_Release date: 26.07.2020_

- Skip string normalization within 'pyproject.toml' config file
- Generate '\__all\__' attribute

0.0.13
========

_Release date: 30.05.2020_

- Integrate interrogate docstring tool

0.0.12
========

_Release date: 10.05.2020_

- Introduce github.io pages configuration file
- Split supported python versions with comma
- Set theme jekyll-theme-cayman
- Implement colored output
- Implement line multiplier
- Return success for code analysis tool

0.0.11
========

_Release date: 23.04.2020_

- Update code badges according to new organisation

0.0.10
========

_Release date: 22.04.2020_

- Add 'flake8-printf-formatting' package

0.0.9
========

_Release date: 16.04.2020_

- Make analyser executable
- Introduce 'check-manifest' tool

0.0.8
========

_Release date: 16.04.2020_

- Upgrade 'enforce-pep8' package
- Ignore 'I100' flake8 rule
- Describe additional meta data for packaging
- Conform python class naming with forward dunder

0.0.7
========

_Release date: 14.04.2020_

- Include Procfile into packaging

0.0.6
========

_Release date: 14.04.2020_

- Save current installed python dependencies
- Add PYPI badges

0.0.5
========

_Release date: 10.04.2020_

- Enhance pypan tool help
- Introduce extra packaging files
- Add pretty python interpreters to dev requirements
- Support 'pytest-mock' plugin
- Upgrade 'enforce-pep8' package

0.0.4
========

_Release date: 06.04.2020_

- Use 100 lines of code
- Support 'back to top' readme navigation

0.0.3
========

_Release date: 05.04.2020_

- Specify local debug section

0.0.2
========

_Release date: 05.04.2020_

- Describe demo usage

0.0.1
========

_Release date: 05.04.2020_

- Support colored user prompt
- Build project environment setup
- Include runtime.txt template file
- Fix code analyser linters
- Show tool usage
- Add 'disallow_subclassing_any' argument to mypy tool
- Introduce template folder
- Introduce package template metafiles
- Define 'pypans' package name
- Introduce initial version of a project
